@@ -58,6 +58,7 @@ class UserView(FlaskView):
 
     @route('/all.txt')
     def all_configs(self):
+        mode=request.args.get("mode")
         c=get_common_data(g.user_uuid,mode)
         # response.content_type = 'text/plain';
         
@@ -89,7 +90,7 @@ def get_common_data(user_uuid,mode):
                 direct_host=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
                 direct_domain_db=Domain(domain=direct_host,mode=DomainType.direct)
             
-            domains.append(db_domain)
+            domains.append(direct_domain_db)
         
         
 
